@@ -10,7 +10,22 @@ __all__ = ['Mod']
 class Mod(base.Blueprint):
     """A Blueprint Mod modifies other blueprints (or mastered blueprints).
 
-    The mod itself can be mastered first, or applied directly.
+    The mod itself can be mastered first, or applied directly. Mods
+    always return mastered items. An example::
+
+        >>> import blueprint as bp
+        >>> class Magical(bp.Mod):
+        ...     name = bp.FormatTemplate('magical {meta.source.name}')
+        ...     quality = lambda _: _.meta.source.quality * 1.2
+        ...     value = bp.RandomInt(2, 10)
+
+        >>> item = Magical(Item)  # ``Item`` from example on ``blueprint.Blueprint``
+        >>> item.name
+        "magical generic item"
+        >>> 1.2 <= item.quality <= (6*1.2)
+        True
+        >>> 2 <= item.value <= 10
+        True
     """
     def __new__(cls, source=None, *args, **kwargs):
         base_mod = super(Mod, cls).__new__(cls, *args, **kwargs)
